@@ -78,7 +78,7 @@ bool Box_Reports::fill_from_database()
   bool result = Box_DB_Table::fill_from_database();
 
   //Enable/Disable extra widgets:
-  bool developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
+  bool developer_mode = (get_userlevel() == AppState::userlevels::DEVELOPER);
 
   //Developers see more columns, so make it bigger:
   if(developer_mode)
@@ -93,14 +93,14 @@ bool Box_Reports::fill_from_database()
 
   const bool editable = developer_mode;
   const bool visible_extras = developer_mode;
-  m_colReportName = m_AddDel.add_column(_("Name"), AddDelColumnInfo::STYLE_Text, editable, visible_extras);
+  m_colReportName = m_AddDel.add_column(_("Name"), AddDelColumnInfo::enumStyles::Text, editable, visible_extras);
   m_AddDel.prevent_duplicates(m_colReportName); //Don't allow a relationship to be added twice.
   m_AddDel.set_prevent_duplicates_warning(_("This report already exists. Please choose a different report name"));
 
-  m_colTitle = m_AddDel.add_column(_("Title"), AddDelColumnInfo::STYLE_Text, editable, true);
+  m_colTitle = m_AddDel.add_column(_("Title"), AddDelColumnInfo::enumStyles::Text, editable, true);
 
   std::vector<Glib::ustring> listTableReports;
-  Document* document = get_document();
+  auto document = get_document();
   if(document)
   {
     for(const auto& item : document->get_report_names(m_table_name))
@@ -162,7 +162,7 @@ void Box_Reports::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
 {
   Glib::ustring report_name = m_AddDel.get_value_key(row);
 
-  Document* document = get_document();
+  auto document = get_document();
   if(document)
   {
      save_to_document();
@@ -175,7 +175,7 @@ void Box_Reports::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Box_Reports::save_to_document()
 {
-  if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
+  if(get_userlevel() == AppState::userlevels::DEVELOPER)
   {
     //Add any reports that are not in the document:
     std::vector<Glib::ustring> listReports = get_document()->get_report_names(m_table_name);
@@ -187,7 +187,7 @@ void Box_Reports::save_to_document()
 
       if(!report_name.empty() && std::find(listReports.begin(), listReports.end(), report_name) == listReports.end())
       {
-        std::shared_ptr<Report> report(new Report());
+        auto report = std::make_shared<Report>();
         report->set_name(report_name);
 
         report->set_title( m_AddDel.get_value(item, m_colTitle) , AppWindow::get_current_locale()); //TODO: Translations: Store the original in the TreeView.
@@ -205,10 +205,10 @@ void Box_Reports::save_to_document()
 
 void Box_Reports::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint column)
 {
-  if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
+  if(get_userlevel() == AppState::userlevels::DEVELOPER)
   {
     const auto report_name = m_AddDel.get_value_key(row);
-    Document* document = get_document();
+    auto document = get_document();
 
     std::shared_ptr<Report> report = document->get_report(m_table_name, report_name);
     if(report)
