@@ -336,37 +336,37 @@ Dialog_ExistingOrNew::Action Dialog_ExistingOrNew::get_action_impl(Gtk::TreeMode
   if(m_notebook->get_current_page() == 0)
   {
     if(m_existing_view->get_selection()->count_selected_rows() == 0)
-      return NONE;
+      return Action::NONE;
 
     iter = m_existing_view->get_selection()->get_selected();
     if(m_existing_model->is_ancestor(m_iter_existing_recent, iter))
-      return OPEN_URI;
+      return Action::OPEN_URI;
 #ifndef G_OS_WIN32
     if(m_existing_model->is_ancestor(m_iter_existing_network, iter))
-      return OPEN_REMOTE;
+      return Action::OPEN_REMOTE;
 #endif
     if(iter == m_iter_existing_other)
-      return OPEN_URI;
+      return Action::OPEN_URI;
 
-    return NONE;
+    return Action::NONE;
   }
   else
   {
     #ifndef GLOM_ENABLE_CLIENT_ONLY
     if(m_new_view->get_selection()->count_selected_rows() == 0)
-      return NONE;
+      return Action::NONE;
 
     iter = m_new_view->get_selection()->get_selected();
     if(m_new_model->is_ancestor(m_iter_new_template, iter))
-      return NEW_FROM_TEMPLATE;
+      return Action::NEW_FROM_TEMPLATE;
     else if(iter == m_iter_new_empty)
-      return NEW_EMPTY;
+      return Action::NEW_EMPTY;
     else
-      return NONE;
+      return Action::NONE;
     #endif //GLOM_ENABLE_CLIENT_ONLY
   }
 
-  return NONE;
+  return Action::NONE;
 }
 
 Dialog_ExistingOrNew::Action Dialog_ExistingOrNew::get_action() const
@@ -381,13 +381,13 @@ Glib::ustring Dialog_ExistingOrNew::get_uri() const
   const auto action = get_action_impl(iter);
 
   #ifndef GLOM_ENABLE_CLIENT_ONLY
-  if(action == NEW_FROM_TEMPLATE)
+  if(action == Action::NEW_FROM_TEMPLATE)
   {
     return (*iter)[m_new_columns.m_col_template_uri];
   }
   else
   #endif //GLOM_ENABLE_CLIENT_ONLY
-  if(action == OPEN_URI)
+  if(action == Action::OPEN_URI)
   {
     if(iter == m_iter_existing_other)
     {
@@ -411,7 +411,7 @@ EpcServiceInfo* Dialog_ExistingOrNew::get_service_info() const
   Gtk::TreeModel::iterator iter;
   Action action = get_action_impl(iter);
 
-  if(action == OPEN_REMOTE)
+  if(action == Action::OPEN_REMOTE)
     return (*iter)[m_existing_columns.m_col_service_info];
   else
     throw std::logic_error("Dialog_ExistingOrNew::get_service_info: action is not OPEN_REMOTE");
@@ -424,7 +424,7 @@ Glib::ustring Dialog_ExistingOrNew::get_service_name() const
   Gtk::TreeModel::iterator iter;
   Action action = get_action_impl(iter);
 
-  if(action == OPEN_REMOTE)
+  if(action == Action::OPEN_REMOTE)
     return (*iter)[m_existing_columns.m_col_service_name];
   else
     throw std::logic_error("Dialog_ExistingOrNew::get_service_name: action is not OPEN_REMOTE");
@@ -435,7 +435,7 @@ std::shared_ptr<Gtk::TreeModel::iterator> Dialog_ExistingOrNew::create_dummy_ite
 {
   auto iter = m_existing_model->append(parent->children());
   (*iter)[m_existing_columns.m_col_title] = text;
-  return std::shared_ptr<Gtk::TreeModel::iterator>(new Gtk::TreeModel::iterator(iter));
+  return std::make_shared<Gtk::TreeModel::iterator>(iter);
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -443,13 +443,13 @@ std::shared_ptr<Gtk::TreeModel::iterator> Dialog_ExistingOrNew::create_dummy_ite
 {
   auto iter = m_new_model->append(parent->children());
   (*iter)[m_new_columns.m_col_title] = text;
-  return std::shared_ptr<Gtk::TreeModel::iterator>(new Gtk::TreeModel::iterator(iter));
+  return std::make_shared<Gtk::TreeModel::iterator>(iter);
 }
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
 void Dialog_ExistingOrNew::existing_icon_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
-  Gtk::CellRendererPixbuf* pixbuf_renderer = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
+  auto pixbuf_renderer = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
   if(!pixbuf_renderer)
   throw std::logic_error("Renderer not a pixbuf renderer in existing_icon_data_func");
 
@@ -460,9 +460,9 @@ void Dialog_ExistingOrNew::existing_icon_data_func(Gtk::CellRenderer* renderer,
   if(iter == m_iter_existing_recent)
     pixbuf_renderer->property_icon_name() = "folder";
 
-  pixbuf_renderer->set_property("stock-size", Gtk::ICON_SIZE_BUTTON);
+  pixbuf_renderer->property_stock_size() = Gtk::ICON_SIZE_BUTTON;
   pixbuf_renderer->property_icon_name() = std::string();
-  pixbuf_renderer->set_property("pixbuf", Glib::RefPtr<Gdk::Pixbuf>());
+  pixbuf_renderer->property_pixbuf() = Glib::RefPtr<Gdk::Pixbuf>();
 
   if(iter == m_iter_existing_recent)
     pixbuf_renderer->property_icon_name() = "folder";
@@ -484,13 +484,13 @@ void Dialog_ExistingOrNew::existing_icon_data_func(Gtk::CellRenderer* renderer,
     {
       //Glib::RefPtr<Gtk::RecentInfo> info = (*iter)[m_existing_columns.m_col_recent_info];
       //pixbuf_renderer->property_pixbuf() = (*info)->get_icon(Gtk::ICON_SIZE_BUTTON);
-      pixbuf_renderer->set_property("icon-name", Glib::ustring("glom"));
+      pixbuf_renderer->property_icon_name() = Glib::ustring("glom");
     }
 #ifndef G_OS_WIN32
     else if(m_existing_model->is_ancestor(m_iter_existing_network, iter))
     {
       //pixbuf_renderer->property_icon_name() = Gtk::Stock::CONNECT.id;
-      pixbuf_renderer->set_property("icon-name", Glib::ustring("glom"));
+      pixbuf_renderer->property_icon_name() = Glib::ustring("glom");
     }
 #endif
     else
@@ -502,7 +502,7 @@ void Dialog_ExistingOrNew::existing_icon_data_func(Gtk::CellRenderer* renderer,
 
 void Dialog_ExistingOrNew::existing_title_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
-  Gtk::CellRendererText* text_renderer = dynamic_cast<Gtk::CellRendererText*>(renderer);
+  auto text_renderer = dynamic_cast<Gtk::CellRendererText*>(renderer);
   if(!text_renderer)
     throw std::logic_error("Renderer not a text renderer in existing_title_data_func");
 
@@ -526,7 +526,7 @@ void Dialog_ExistingOrNew::existing_title_data_func(Gtk::CellRenderer* renderer,
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Dialog_ExistingOrNew::new_icon_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
-  Gtk::CellRendererPixbuf* pixbuf_renderer = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
+  auto pixbuf_renderer = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
   if(!pixbuf_renderer)
     throw std::logic_error("Renderer not a pixbuf renderer in new_icon_data_func");
 
@@ -544,7 +544,7 @@ void Dialog_ExistingOrNew::new_icon_data_func(Gtk::CellRenderer* renderer, const
   {
     if(m_new_model->is_ancestor(m_iter_new_template, iter))
     {
-      pixbuf_renderer->set_property("icon-name", Glib::ustring("glom"));
+      pixbuf_renderer->property_icon_name() = Glib::ustring("glom");
     }
     else
     {
@@ -555,7 +555,7 @@ void Dialog_ExistingOrNew::new_icon_data_func(Gtk::CellRenderer* renderer, const
 
 void Dialog_ExistingOrNew::new_title_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
-  Gtk::CellRendererText* text_renderer = dynamic_cast<Gtk::CellRendererText*>(renderer);
+  auto text_renderer = dynamic_cast<Gtk::CellRendererText*>(renderer);
   if(!text_renderer)
     throw std::logic_error("Renderer not a text renderer in new_title_data_func");
 
@@ -796,7 +796,7 @@ void Dialog_ExistingOrNew::on_select_clicked()
   Gtk::TreeModel::iterator iter;
   Action action = get_action_impl(iter);
 
-  if(action == OPEN_URI && iter == m_iter_existing_other)
+  if(action == Action::OPEN_URI && iter == m_iter_existing_other)
   {
     Gtk::FileChooserDialog dialog(*this, "Open Glom File");
     dialog.add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL);
