@@ -75,7 +75,7 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 : PlaceHolder(cobject, builder),
   m_pLabel_Table_DataMode(nullptr),
   m_pLabel_Table_FindMode(nullptr),
-  m_Box_RecordsCount(Gtk::ORIENTATION_HORIZONTAL, UiUtils::DEFAULT_SPACING_SMALL),
+  m_Box_RecordsCount(Gtk::ORIENTATION_HORIZONTAL, Utils::to_utype(UiUtils::DefaultSpacings::SMALL)),
   m_Button_FindAll(_("Find All")),
   m_stack_mode(nullptr),
   m_pBox_Tables(nullptr),
@@ -107,8 +107,8 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 
   //QuickFind widgets:
   //We don't use Glade for these, so it easier to modify them for the Maemo port.
-  m_pBox_QuickFind = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, UiUtils::DEFAULT_SPACING_SMALL));
-  Gtk::Label* label = Gtk::manage(new Gtk::Label(_("Quick _search:"), true));
+  m_pBox_QuickFind = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, Utils::to_utype(UiUtils::DefaultSpacings::SMALL)));
+  auto label = Gtk::manage(new Gtk::Label(_("Quick _search:"), true));
   m_pBox_QuickFind->pack_start(*label, Gtk::PACK_SHRINK);
 
   m_pEntry_QuickFind = Gtk::manage(new Gtk::Entry());
@@ -154,8 +154,8 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
     m_Notebook_Data.set_enable_layout_drag_and_drop(false);
   }
 
-  m_Mode = MODE_None;
-  m_Mode_Previous = MODE_None;
+  m_Mode = enumModes::NONE;
+  m_Mode_Previous = enumModes::NONE;
 
 
   m_Notebook_Find.signal_find_criteria.connect(sigc::mem_fun(*this, &Frame_Glom::on_notebook_find_criteria));
@@ -171,7 +171,7 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   add_view(&m_Notebook_Data); //Also a composite view.
   add_view(&m_Notebook_Find); //Also a composite view.
 
-  on_userlevel_changed(AppState::USERLEVEL_OPERATOR); //A default to show before a document is created or loaded.
+  on_userlevel_changed(AppState::userlevels::OPERATOR); //A default to show before a document is created or loaded.
 }
 
 Frame_Glom::~Frame_Glom()
@@ -274,14 +274,14 @@ bool Frame_Glom::set_mode(enumModes mode)
   const bool changed = (m_Mode != mode);
 
   //Choose a default mode, if necessary:
-  if(mode == MODE_None)
-    mode = MODE_Data;
+  if(mode == enumModes::NONE)
+    mode = enumModes::DATA;
 
   m_Mode_Previous = m_Mode;
   m_Mode = mode;
 
   //Hide the Quick Find widgets if we are not in Find mode.
-  const bool show_quickfind = (m_Mode == MODE_Find);
+  const bool show_quickfind = (m_Mode == enumModes::FIND);
   if(show_quickfind)
   {
     m_pBox_QuickFind->show();
@@ -302,7 +302,7 @@ bool Frame_Glom::set_mode(enumModes mode)
 
 
   //Show the main part of the UI:
-  if(m_Mode == MODE_Find)
+  if(m_Mode == enumModes::FIND)
     set_mode_widget(m_Notebook_Find);
   else
     set_mode_widget(m_Notebook_Data);
@@ -313,7 +313,7 @@ bool Frame_Glom::set_mode(enumModes mode)
 void Frame_Glom::alert_no_table()
 {
   //Ask user to choose a table first:
-  Gtk::Window* pWindowApp = get_app_window();
+  auto pWindowApp = get_app_window();
   if(pWindowApp)
   {
     //TODO: Obviously this document should have been deleted when the database-creation was cancelled.
@@ -329,13 +329,13 @@ void Frame_Glom::show_table_refresh()
 
 void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value_for_details)
 {
-  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
+  auto pApp = dynamic_cast<AppWindow*>(get_app_window());
 
   //This can take quite a long time, so we show the busy cursor while it's working:
   BusyCursor busy_cursor(pApp);
 
   //Choose a default mode, if necessary:
-  if(m_Mode == MODE_None)
+  if(m_Mode == enumModes::NONE)
     set_mode(m_Mode);
 
   //Show the table:
@@ -354,14 +354,14 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
 
   switch(m_Mode)
   {
-    case(MODE_Data):
+    case(enumModes::DATA):
     {
       FoundSet found_set;
 
       //Start with the last-used found set (sort order and where clause)
       //for this layout:
       //(This would be ignored anyway if a details primary key is specified.)
-      Document* document = get_document();
+      auto document = get_document();
       if(document)
         found_set = document->get_criteria_current(m_table_name);
 
@@ -409,7 +409,7 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
 
       break;
     }
-    case(MODE_Find):
+    case(enumModes::FIND):
     {
       m_Notebook_Find.init_db_details(m_table_name, get_active_layout_platform(get_document()));
       set_mode_widget(m_Notebook_Find);
@@ -455,12 +455,12 @@ void Frame_Glom::show_no_table()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 bool Frame_Glom::attempt_change_usermode_to_developer()
 {
-  Document* document = dynamic_cast<Document*>(get_document());
+  auto document = dynamic_cast<Document*>(get_document());
   if(!document)
     return false;
 
   //Check whether the current user has developer privileges:
-  ConnectionPool* connection_pool = ConnectionPool::get_instance();
+  auto connection_pool = ConnectionPool::get_instance();
       std::shared_ptr<SharedConnection> sharedconnection = connection_pool->connect();
 
   // Default to true; if we don't support users, we always have
@@ -476,10 +476,10 @@ bool Frame_Glom::attempt_change_usermode_to_developer()
   {
     std::cout << "DEBUG: User=" << connection_pool->get_user() << " _is_ in the developer group on the server." << std::endl;
     //Avoid double signals:
-    //if(document->get_userlevel() != AppState::USERLEVEL_DEVELOPER)
-    test = document->set_userlevel(AppState::USERLEVEL_DEVELOPER);
+    //if(document->get_userlevel() != AppState::userlevels::DEVELOPER)
+    test = document->set_userlevel(AppState::userlevels::DEVELOPER);
     if(!test)
-      std::cout << "  DEBUG: But document->set_userlevel(AppState::USERLEVEL_DEVELOPER) failed." << std::endl;
+      std::cout << "  DEBUG: But document->set_userlevel(AppState::userlevels::DEVELOPER) failed." << std::endl;
   }
   else
   {
@@ -521,11 +521,11 @@ bool Frame_Glom::attempt_change_usermode_to_developer()
 
 bool Frame_Glom::attempt_change_usermode_to_operator()
 {
-  Document* document = dynamic_cast<Document*>(get_document());
+  auto document = dynamic_cast<Document*>(get_document());
   if(!document)
     return false;
     
-  document->set_userlevel(AppState::USERLEVEL_OPERATOR);
+  document->set_userlevel(AppState::userlevels::OPERATOR);
 
   return true;
 }
@@ -534,13 +534,13 @@ void Frame_Glom::on_menu_file_export()
 {
   //Start with a sequence based on the Details view:
   //The user can changed this by clicking the button in the FileChooser:
-  Document* document = get_document();
+  auto document = get_document();
   if(!document)
     return;
 
   Document::type_list_layout_groups mapGroupSequence = document->get_data_layout_groups_plus_new_fields("details", m_table_name, get_active_layout_platform(document));
 
-  Gtk::Window* pWindowApp = get_app_window();
+  auto pWindowApp = get_app_window();
   g_assert(pWindowApp);
 
   //Do not try to export the data if the user may not view it:
@@ -575,7 +575,7 @@ void Frame_Glom::on_menu_file_export()
 
   const auto found_set = m_Notebook_Data.get_found_set();
 
-  std::fstream the_stream(filepath.c_str(), std::ios_base::out | std::ios_base::trunc);
+  std::fstream the_stream(filepath, std::ios_base::out | std::ios_base::trunc);
   if(!the_stream)
   {
     show_ok_dialog(_("Could Not Create File."), _("Glom could not create the specified file."), *pWindowApp, Gtk::MESSAGE_ERROR);
@@ -618,13 +618,13 @@ void Frame_Glom::export_data_to_vector(Document::type_example_rows& the_vector,
           const auto value = result->get_value_at(col_index, row_index);
 
           std::shared_ptr<const LayoutItem_Field> layout_item = fieldsSequence[col_index];
-          //if(layout_item->m_field.get_glom_type() != Field::TYPE_IMAGE) //This is too much data.
+          //if(layout_item->m_field.get_glom_type() != Field::glom_field_type::IMAGE) //This is too much data.
           //{
 
             //Output data in canonical SQL format, ignoring the user's locale, and ignoring the layout formatting:
             row_data.push_back(value);  //TODO_Performance: reserve the size.
 
-            //if(layout_item->m_field.get_glom_type() == Field::TYPE_IMAGE) //This is too much data.
+            //if(layout_item->m_field.get_glom_type() == Field::glom_field_type::IMAGE) //This is too much data.
             //{
              //std::cout << "  field name=" << layout_item->get_name() << ", value=" << layout_item->m_field.sql(value) << std::endl;
             //}
@@ -668,7 +668,7 @@ void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet&
           const auto value = result->get_value_at(col_index, row_index);
 
           std::shared_ptr<const LayoutItem_Field> layout_item = fieldsSequence[col_index];
-          //if(layout_item->m_field.get_glom_type() != Field::TYPE_IMAGE) //This is too much data.
+          //if(layout_item->m_field.get_glom_type() != Field::glom_field_type::IMAGE) //This is too much data.
           //{
             if(!row_string.empty())
               row_string += ",";
@@ -683,7 +683,7 @@ void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet&
 
             const auto field_text = field->to_file_format(value);
 
-            if(layout_item->get_glom_type() == Field::TYPE_IMAGE) //This is too much data.
+            if(layout_item->get_glom_type() == Field::glom_field_type::IMAGE) //This is too much data.
             {
               // Some extra debug checks,
               // though we believe that all these problems are now fixed in File::to_file_format():
@@ -705,7 +705,7 @@ void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet&
               }
             }
 
-            if(layout_item->get_glom_type() == Field::TYPE_TEXT)
+            if(layout_item->get_glom_type() == Field::glom_field_type::TEXT)
             {
               //The CSV RFC says text may be quoted and should be if it has newlines:
               //TODO: Escape the text?
@@ -800,8 +800,8 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
 {
   //Prevent this change if not in developer mode,
   //though the menu item should be disabled then anyway.
-  Document* document = dynamic_cast<Document*>(get_document());
-  if(!document || document->get_userlevel() != AppState::USERLEVEL_DEVELOPER)
+  auto document = dynamic_cast<Document*>(get_document());
+  if(!document || document->get_userlevel() != AppState::userlevels::DEVELOPER)
     return false;
 
   if(shared == document->get_network_shared())
@@ -844,7 +844,7 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
         if(initial_password_provided && added)
         {
           //Use the new user/password from now on:
-          ConnectionPool* connectionpool = ConnectionPool::get_instance();
+          auto connectionpool = ConnectionPool::get_instance();
           connectionpool->set_user(user);
           connectionpool->set_password(password);
         }
@@ -879,14 +879,14 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
         if(default_user_exists)
         {
           //Force a reconnection with the new password:
-          //ConnectionPool* connectionpool = ConnectionPool::get_instance();
+          //auto connectionpool = ConnectionPool::get_instance();
 
           //Remove it, after stopping it from being the database owner:
           bool disabled = true;
           Glib::ustring default_password;
           const auto default_user = Privs::get_default_developer_user_name(default_password, hosting_mode);
 
-          ConnectionPool* connectionpool = ConnectionPool::get_instance();
+          auto connectionpool = ConnectionPool::get_instance();
           const auto reowned = set_database_owner_user(connectionpool->get_user());
           bool removed = false;
           if(reowned)
@@ -969,7 +969,7 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
   //and start it again:
   if(change)
   {
-    ConnectionPool* connectionpool = ConnectionPool::get_instance();
+    auto connectionpool = ConnectionPool::get_instance();
     std::shared_ptr<SharedConnection> sharedconnection = connectionpool->connect();
     if(sharedconnection)
     {
@@ -984,7 +984,7 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
     connectionpool->set_network_shared(sigc::mem_fun(*this, &Frame_Glom::on_connection_startup_progress), shared);
     const ConnectionPool::StartupErrors started =
       connectionpool->startup( sigc::mem_fun(*this, &Frame_Glom::on_connection_startup_progress) );
-    if(started != ConnectionPool::Backend::STARTUPERROR_NONE)
+    if(started != ConnectionPool::Backend::StartupErrors::NONE)
     {
       //TODO: Output more exact details of the error message.
       //TODO: Recover somehow?
@@ -996,7 +996,7 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
   }
 
   //Update the UI:
-  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
+  auto pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
   {
     pApp->update_network_shared_ui();
@@ -1008,7 +1008,7 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
 
 void Frame_Glom::on_menu_file_print()
 {
- Notebook_Glom* notebook_current = dynamic_cast<Notebook_Glom*>(m_stack_mode->get_visible_child());
+ auto notebook_current = dynamic_cast<Notebook_Glom*>(m_stack_mode->get_visible_child());
  if(notebook_current)
    notebook_current->do_menu_file_print();
 }
@@ -1033,17 +1033,17 @@ void Frame_Glom::set_mode_find()
   //It shouldn't, but until we fix that, let's show the busy cursor while it's working:
   BusyCursor busy_cursor(get_app_window());
 
-  const bool previously_in_data_mode = (m_Mode == MODE_Data);
+  const bool previously_in_data_mode = (m_Mode == enumModes::DATA);
 
   const auto list_or_details = m_Notebook_Data.get_current_view();
 
   //A workaround hack to make sure that the list view will be active when the results are shown.
   //Because the list doesn't refresh properly (to give the first result) when the Details view was active first.
   //murrayc.
-  if(previously_in_data_mode && (list_or_details == Notebook_Data::DATA_VIEW_Details))
-    m_Notebook_Data.set_current_view(Notebook_Data::DATA_VIEW_List);
+  if(previously_in_data_mode && (list_or_details == Notebook_Data::dataview::DETAILS))
+    m_Notebook_Data.set_current_view(Notebook_Data::dataview::LIST);
 
-  if(!set_mode(MODE_Find))
+  if(!set_mode(enumModes::FIND))
     return;
 
   show_table(m_table_name);
@@ -1058,7 +1058,7 @@ void Frame_Glom::set_mode_find()
 void Frame_Glom::set_mode_data()
 {
   //Switch to data mode
-  if(!set_mode(MODE_Data))
+  if(!set_mode(enumModes::DATA))
     return;
 
   //This would lose the current found set, if any:
@@ -1109,7 +1109,7 @@ void Frame_Glom::on_menu_Tables_AddRelatedTable()
 
   m_dialog_addrelatedtable->signal_response().connect( sigc::mem_fun(*this, &Frame_Glom::on_dialog_add_related_table_response) );
 
-  Gtk::Window* parent = get_app_window();
+  auto parent = get_app_window();
 
   if(parent)
     m_dialog_addrelatedtable->set_transient_for(*parent);
@@ -1136,7 +1136,7 @@ void Frame_Glom::on_dialog_add_related_table_response(int response)
     Glib::ustring table_name, relationship_name, from_key_name;
     m_dialog_addrelatedtable->get_input(table_name, relationship_name, from_key_name);
 
-    Gtk::Window* parent = get_app_window();
+    auto parent = get_app_window();
 
     //It would be nice to put this in the dialog's on_response() instead,
     //but I don't think we can stop the response from being returned. murrayc
@@ -1194,7 +1194,7 @@ void Frame_Glom::on_dialog_add_related_table_response(int response)
       relationship->set_allow_edit(true);
       relationship->set_auto_create(true);
 
-      Document* document = get_document();
+      auto document = get_document();
       if(!document)
         return;
 
@@ -1236,7 +1236,7 @@ void Frame_Glom::do_menu_Navigate_Table(bool open_default)
     m_pDialog_Tables = new Window_BoxHolder(m_pBox_Tables, _("Edit Tables"));
     m_pDialog_Tables->signal_hide().connect(sigc::mem_fun(*this, &Frame_Glom::on_dialog_tables_hide));
 
-    Gtk::Window* pWindow = get_app_window();
+    auto pWindow = get_app_window();
     if(pWindow)
       m_pDialog_Tables->set_transient_for(*pWindow);
 
@@ -1269,17 +1269,17 @@ void Frame_Glom::do_menu_Navigate_Table(bool open_default)
 
 const Gtk::Window* Frame_Glom::get_app_window() const
 {
-  Frame_Glom* nonconst = const_cast<Frame_Glom*>(this);
+  auto nonconst = const_cast<Frame_Glom*>(this);
   return nonconst->get_app_window();
 }
 
 Gtk::Window* Frame_Glom::get_app_window()
 {
-  Gtk::Widget* pWidget = get_parent();
+  auto pWidget = get_parent();
   while(pWidget)
   {
     //Is this widget a Gtk::Window?:
-    Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(pWidget);
+    auto pWindow = dynamic_cast<Gtk::Window*>(pWidget);
     if(pWindow)
     {
       //Yes, return it.
@@ -1309,7 +1309,7 @@ void Frame_Glom::on_button_quickfind()
 
 void Frame_Glom::on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clause)
 {
-  AppWindow* app = dynamic_cast<AppWindow*>(get_app_window());
+  auto app = dynamic_cast<AppWindow*>(get_app_window());
   if(!app)
   {
     std::cerr << G_STRFUNC << ": get_app_window() failed." << std::endl;
@@ -1392,7 +1392,7 @@ void Frame_Glom::on_userlevel_changed(AppState::userlevels /* userlevel */)
 
 void Frame_Glom::show_table_title()
 {
-  Document* document = dynamic_cast<Document*>(get_document());
+  auto document = dynamic_cast<Document*>(get_document());
   if(!document)
     return;
 
@@ -1400,7 +1400,7 @@ void Frame_Glom::show_table_title()
   Glib::ustring table_label = document->get_table_title(m_table_name, AppWindow::get_current_locale());
   if(!table_label.empty())
   {
-    if(document->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
+    if(document->get_userlevel() == AppState::userlevels::DEVELOPER)
       table_label += " (" + m_table_name + ")"; //Show the table name as well, if in developer mode.
   }
   else //Use the table name if there is no table title.
@@ -1432,7 +1432,7 @@ void Frame_Glom::update_table_in_document_from_database()
       " Falling back to the field details in the document." << std::endl;
   }
 
-  Document* pDoc = dynamic_cast<Document*>(get_document());
+  auto pDoc = dynamic_cast<Document*>(get_document());
   if(pDoc)
   {
     bool document_must_be_updated = false;
@@ -1446,7 +1446,7 @@ void Frame_Glom::update_table_in_document_from_database()
       if(field_database)
       {
         //Is the field already in the document?
-        auto iterFindDoc = std::find_if( fieldsDocument.begin(), fieldsDocument.end(), predicate_FieldHasName<Field>( field_database->get_name() ) );
+        auto iterFindDoc = find_if_same_name(fieldsDocument, field_database->get_name());
         if(iterFindDoc == fieldsDocument.end()) //If it was not found:
         {
           //Add it
@@ -1491,7 +1491,7 @@ void Frame_Glom::update_table_in_document_from_database()
       for(const auto& field : fieldsDocument)
       {
         //Check whether it's in the database:
-        auto iterFindDatabase = std::find_if( fieldsDatabase.begin(), fieldsDatabase.end(), predicate_FieldHasName<Field>( field->get_name() ) );
+        auto iterFindDatabase = find_if_same_name(fieldsDatabase, field->get_name());
         if(iterFindDatabase != fieldsDatabase.end()) //If it was found
         {
           fieldsActual.push_back(field);
@@ -1513,7 +1513,7 @@ void Frame_Glom::set_document(Document* pDocument)
 {
   View_Composite_Glom::set_document(pDocument);
 
-  Document* document = get_document();
+  auto document = get_document();
   if(document)
   {
     //Connect to a signal that is only on the derived document class:
@@ -1526,7 +1526,7 @@ void Frame_Glom::set_document(Document* pDocument)
 
 void Frame_Glom::load_from_document()
 {
-  Document* document = dynamic_cast<Document*>(get_document());
+  auto document = dynamic_cast<Document*>(get_document());
   if(document)
   {
     //Call base class:
@@ -1556,7 +1556,7 @@ void Frame_Glom::on_menu_developer_database_preferences()
 
 void Frame_Glom::on_menu_developer_fields()
 {
-  Gtk::Window* parent = get_app_window();
+  auto parent = get_app_window();
   if(parent)
     do_menu_developer_fields(*parent);
 
@@ -1574,8 +1574,8 @@ void Frame_Glom::do_menu_developer_fields(Gtk::Window& parent, const Glib::ustri
   // Some database backends (SQLite) require the table to change to no longer
   // be in use when changing the records, so we stop the database usage
   // here. We reshow everything in on_developer_dialog_hide() anyway.
-  Document* document = dynamic_cast<Document*>(get_document());
-  if(document && document->get_hosting_mode() == Document::HOSTING_MODE_SQLITE)
+  auto document = dynamic_cast<Document*>(get_document());
+  if(document && document->get_hosting_mode() == Document::HostingMode::SQLITE)
     show_no_table();
 
   // Remember the old table name so that we re-show the previous table as
@@ -1628,7 +1628,7 @@ void Frame_Glom::do_menu_developer_relationships(Gtk::Window& parent, const Glib
     Utils::get_glade_widget_derived_with_warning(m_pDialog_Relationships);
     if(!m_pDialog_Relationships)
     {
-      std::cerr << G_STRFUNC << ": m_pDialog_Relationships is null." << std::cerr;
+      std::cerr << G_STRFUNC << ": m_pDialog_Relationships is null." << std::endl;
       return;
     }
     
@@ -1648,7 +1648,7 @@ void Frame_Glom::on_menu_developer_relationships()
   if(m_table_name.empty())
     return;
 
-  Gtk::Window* app = get_app_window();
+  auto app = get_app_window();
   if(app)
     do_menu_developer_relationships(*app, m_table_name);
 }
@@ -1681,7 +1681,7 @@ void Frame_Glom::on_menu_developer_layout()
   if(m_table_name.empty())
     return;
 
-  Notebook_Glom* notebook_current = dynamic_cast<Notebook_Glom*>(m_stack_mode->get_visible_child());
+  auto notebook_current = dynamic_cast<Notebook_Glom*>(m_stack_mode->get_visible_child());
   if(notebook_current)
     notebook_current->do_menu_developer_layout();
 }
@@ -1699,7 +1699,7 @@ void Frame_Glom::on_menu_developer_reports()
       Utils::get_glade_child_widget_derived_with_warning(m_pBox_Reports);
     if(!m_pBox_Reports)
     {
-      std::cerr << G_STRFUNC << ": m_pBox_Reports is null." << std::cerr;
+      std::cerr << G_STRFUNC << ": m_pBox_Reports is null." << std::endl;
       return;
     }
 
@@ -1798,7 +1798,7 @@ void Frame_Glom::add_window_to_app(Gtk::ApplicationWindow* window)
     return;
   }
 
-  Gtk::Window* app_window = get_app_window();
+  auto app_window = get_app_window();
   if(!app_window)
   {
     std::cerr << G_STRFUNC << ": app_window is null" << std::endl;
@@ -1817,7 +1817,7 @@ void Frame_Glom::add_window_to_app(Gtk::ApplicationWindow* window)
 
 void Frame_Glom::on_box_print_layouts_selected(const Glib::ustring& print_layout_name)
 {
-  Gtk::Window* app_window = get_app_window();
+  auto app_window = get_app_window();
   if(!app_window)
   {
     std::cerr << G_STRFUNC << ": app_window is null" << std::endl;
@@ -1896,19 +1896,19 @@ bool Frame_Glom::handle_connection_initialize_errors(ConnectionPool::InitErrors
   Glib::ustring title;
   Glib::ustring message;
 
-  if(error == ConnectionPool::Backend::INITERROR_NONE)
+  if(error == ConnectionPool::Backend::InitErrors::NONE)
     return true;
-  else if(error == ConnectionPool::Backend::INITERROR_DIRECTORY_ALREADY_EXISTS)
+  else if(error == ConnectionPool::Backend::InitErrors::DIRECTORY_ALREADY_EXISTS)
   {
     title = _("Directory Already Exists");
     message = _("There is an existing directory with the same name as the directory that should be created for the new database files. You should specify a different filename to use a new directory instead.");
   }
-  else if(error == ConnectionPool::Backend::INITERROR_COULD_NOT_CREATE_DIRECTORY)
+  else if(error == ConnectionPool::Backend::InitErrors::COULD_NOT_CREATE_DIRECTORY)
   {
     title = _("Could Not Create Directory");
     message = _("There was an error when attempting to create the directory for the new database files.");
   }
-  else if(error == ConnectionPool::Backend::INITERROR_COULD_NOT_START_SERVER)
+  else if(error == ConnectionPool::Backend::InitErrors::COULD_NOT_START_SERVER)
   {
     title = _("Could Not Start Database Server");
     message = _("There was an error when attempting to start the database server.");
@@ -1926,12 +1926,12 @@ bool Frame_Glom::connection_request_initial_password(Glib::ustring& user, Glib::
   user = Glib::ustring();
   password = Glib::ustring();
 
-  Document* document = dynamic_cast<Document*>(get_document());
+  auto document = dynamic_cast<Document*>(get_document());
   if(!document)
     return false;
 
   //This is only useful for self-hosted postgres:
-  if(document->get_hosting_mode() != Document::HOSTING_MODE_POSTGRES_SELF)
+  if(document->get_hosting_mode() != Document::HostingMode::POSTGRES_SELF)
     return false;
 
   //Ask for a new username and password to specify when creating a new self-hosted database.
@@ -1978,11 +1978,11 @@ bool Frame_Glom::connection_request_initial_password(Glib::ustring& user, Glib::
 
 bool Frame_Glom::connection_request_password_and_choose_new_database_name()
 {
-  Document* document = dynamic_cast<Document*>(get_document());
+  auto document = dynamic_cast<Document*>(get_document());
   if(!document)
     return false;
 
-  ConnectionPool* connection_pool = ConnectionPool::get_instance();
+  auto connection_pool = ConnectionPool::get_instance();
   connection_pool->setup_from_document(document);
 
   if(!m_pDialogConnection)
@@ -1990,7 +1990,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     Utils::get_glade_widget_derived_with_warning(m_pDialogConnection);
     if(!m_pDialogConnection)
     {
-      std::cerr << G_STRFUNC << ": m_pBox_Reports is null." << std::cerr;
+      std::cerr << G_STRFUNC << ": m_pBox_Reports is null." << std::endl;
       return false;
     }
 
@@ -2000,8 +2000,8 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
   const auto hosting_mode = document->get_hosting_mode();
   switch(hosting_mode)
   {
-    case Document::HOSTING_MODE_POSTGRES_SELF:
-    case Document::HOSTING_MODE_MYSQL_SELF:
+    case Document::HostingMode::POSTGRES_SELF:
+    case Document::HostingMode::MYSQL_SELF:
     {
       Glib::ustring user, password;
 
@@ -2040,8 +2040,8 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
 
     break;
 
-    case Document::HOSTING_MODE_POSTGRES_CENTRAL:
-    case Document::HOSTING_MODE_MYSQL_CENTRAL:
+    case Document::HostingMode::POSTGRES_CENTRAL:
+    case Document::HostingMode::MYSQL_CENTRAL:
     {
       //Ask for connection details:
       m_pDialogConnection->load_from_document(); //Get good defaults.
@@ -2073,7 +2073,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
 
     break;
 #ifdef GLOM_ENABLE_SQLITE
-  case Document::HOSTING_MODE_SQLITE:
+  case Document::HostingMode::SQLITE:
     {
       // SQLite:
       ConnectionPool::SlotProgress slot_ignored;
@@ -2095,7 +2095,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
   ShowProgressMessage progress_message(_("Starting Database Server"));
   const ConnectionPool::StartupErrors started =
     connection_pool->startup( sigc::mem_fun(*this, &Frame_Glom::on_connection_startup_progress) );
-  if(started != ConnectionPool::Backend::STARTUPERROR_NONE)
+  if(started != ConnectionPool::Backend::StartupErrors::NONE)
   {
     std::cerr << G_STRFUNC << ": startup() failed." << std::endl;
     //TODO: Output more exact details of the error message.
@@ -2145,7 +2145,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     {
       //std::cerr << G_STRFUNC << ": caught exception." << std::endl;
 
-      if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
+      if(ex.get_failure_type() == ExceptionConnection::failure_type::NO_SERVER)
       {
         //Warn the user, and let him try again:
         UiUtils::show_ok_dialog(_("Connection Failed"), _("Glom could not connect to the database server. Maybe you entered an incorrect user name or password, or maybe the postgres database server is not running."), *(get_app_window()), Gtk::MESSAGE_ERROR); //TODO: Add help button.
@@ -2162,10 +2162,10 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
 
         // Remember host and port if the document is not self hosted
         #ifdef GLOM_ENABLE_POSTGRESQL
-        if(document->get_hosting_mode() == Document::HOSTING_MODE_POSTGRES_CENTRAL)
+        if(document->get_hosting_mode() == Document::HostingMode::POSTGRES_CENTRAL)
         {
-          ConnectionPool::Backend* backend = connection_pool->get_backend();
-          ConnectionPoolBackends::PostgresCentralHosted* central = dynamic_cast<ConnectionPoolBackends::PostgresCentralHosted*>(backend);
+          auto backend = connection_pool->get_backend();
+          auto central = dynamic_cast<ConnectionPoolBackends::PostgresCentralHosted*>(backend);
           g_assert(central);
 
           document->set_connection_server(central->get_host());
@@ -2179,10 +2179,10 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
         // connect_to_server_with_connection_settings, which is just not
         // executed because it failed with no database present. We should
         // somehow avoid this code duplication.
-        else if(document->get_hosting_mode() == Document::HOSTING_MODE_POSTGRES_SELF)
+        else if(document->get_hosting_mode() == Document::HostingMode::POSTGRES_SELF)
         {
-          ConnectionPool::Backend* backend = connection_pool->get_backend();
-          ConnectionPoolBackends::PostgresSelfHosted* self = dynamic_cast<ConnectionPoolBackends::PostgresSelfHosted*>(backend);
+          auto backend = connection_pool->get_backend();
+          auto self = dynamic_cast<ConnectionPoolBackends::PostgresSelfHosted*>(backend);
           g_assert(self);
 
           document->set_connection_port(self->get_port());
@@ -2204,7 +2204,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
 
 void Frame_Glom::cleanup_connection()
 {
-  ConnectionPool* connection_pool = ConnectionPool::get_instance();
+  auto connection_pool = ConnectionPool::get_instance();
   ShowProgressMessage progress_message(_("Stopping Database Server"));
   connection_pool->cleanup( sigc::mem_fun(*this, &Frame_Glom::on_connection_cleanup_progress) );
 }
@@ -2216,13 +2216,13 @@ bool Frame_Glom::handle_request_password_connection_error(bool asked_for_passwor
   //Initialize input parameter:
   database_not_found = false;
 
-  if(asked_for_password && ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
+  if(asked_for_password && ex.get_failure_type() == ExceptionConnection::failure_type::NO_SERVER)
   {
     //Warn the user, and let him try again:
     UiUtils::show_ok_dialog(_("Connection Failed"), _("Glom could not connect to the database server. Maybe you entered an incorrect user name or password, or maybe the postgres database server is not running."), *(get_app_window()), Gtk::MESSAGE_ERROR); //TODO: Add help button.
     return true;
   }
-  else if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_DATABASE)
+  else if(ex.get_failure_type() == ExceptionConnection::failure_type::NO_DATABASE)
   {
     cleanup_connection();
 
@@ -2244,25 +2244,25 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
   //Initialize output parameter:
   database_not_found = false;
 
-  Document* document = dynamic_cast<Document*>(get_document());
+  auto document = dynamic_cast<Document*>(get_document());
   if(!document)
     return false;
 
 
   //Start a self-hosted server if necessary:
-  ConnectionPool* connection_pool = ConnectionPool::get_instance();
+  auto connection_pool = ConnectionPool::get_instance();
   ShowProgressMessage progress_message(_("Starting Database Server"));
   connection_pool->setup_from_document(document);
   const ConnectionPool::StartupErrors started =
     connection_pool->startup( sigc::mem_fun(*this, &Frame_Glom::on_connection_startup_progress) );
-  if(started != ConnectionPool::Backend::STARTUPERROR_NONE)
+  if(started != ConnectionPool::Backend::StartupErrors::NONE)
   {
     std::cerr << G_STRFUNC << ": startup() failed." << std::endl;
     return false;
     //TODO: Output more exact details of the error message.
   }
 
-  AppWindow* app = dynamic_cast<AppWindow*>(get_app_window());
+  auto app = dynamic_cast<AppWindow*>(get_app_window());
   if(!app)
   {
     std::cerr << G_STRFUNC << ": app is null." << std::endl;
@@ -2274,7 +2274,7 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
   //Only ask for the password if we are shared on the network, or we are using a centrally hosted server.
   //Otherwise, no password question is necessary, due to how our self-hosted database server is configured.
   if(document->get_network_shared()
-    || document->get_hosting_mode() == Document::HOSTING_MODE_POSTGRES_CENTRAL)
+    || document->get_hosting_mode() == Document::HostingMode::POSTGRES_CENTRAL)
   {
     //We recreate the dialog each time to make sure it is clean of any changes:
     delete m_pDialogConnection;
@@ -2346,7 +2346,7 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
       else
       {
         //Use the known password:
-        ConnectionPool* connectionpool = ConnectionPool::get_instance();
+        auto connectionpool = ConnectionPool::get_instance();
         connectionpool->set_user(known_username);
         connectionpool->set_password(known_password);
 
@@ -2377,7 +2377,7 @@ bool Frame_Glom::create_database(const Glib::ustring& database_name, const Glib:
 {
   bool result = false;
 
-  Gtk::Window* pWindowApp = get_app_window();
+  auto pWindowApp = get_app_window();
   g_assert(pWindowApp);
 
   {
@@ -2394,7 +2394,7 @@ bool Frame_Glom::create_database(const Glib::ustring& database_name, const Glib:
     Utils::get_glade_widget_with_warning("glom_developer.glade", "dialog_error_create_database", dialog);
     if(!dialog)
     {
-      std::cerr << G_STRFUNC << ": dialog is null." << std::cerr;
+      std::cerr << G_STRFUNC << ": dialog is null." << std::endl;
       return false;
     }
 
@@ -2420,7 +2420,7 @@ void Frame_Glom::on_menu_report_selected(const Glib::ustring& report_name)
     return;
   }
 
-  Document* document = get_document();
+  auto document = get_document();
   std::shared_ptr<Report> report = document->get_report(m_table_name, report_name);
   if(!report)
     return;
@@ -2471,7 +2471,7 @@ void Frame_Glom::do_print_layout(const Glib::ustring& print_layout_name, bool pr
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Frame_Glom::on_dialog_layout_report_hide()
 {
-  Document* document = get_document();
+  auto document = get_document();
 
   if(document && true) //m_pDialogLayoutReport->get_modified())
   {
@@ -2484,14 +2484,14 @@ void Frame_Glom::on_dialog_layout_report_hide()
   }
 
   //Update the reports menu:
-  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
+  auto pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
     pApp->fill_menu_reports(m_table_name);
 }
 
 void Frame_Glom::on_dialog_layout_print_hide()
 {
-  Document* document = get_document();
+  auto document = get_document();
 
   if(document && true) //m_pDialogLayoutReport->get_modified())
   {
@@ -2504,7 +2504,7 @@ void Frame_Glom::on_dialog_layout_print_hide()
   }
 
   //Update the print layouts menu:
-  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
+  auto pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
     pApp->fill_menu_print_layouts(m_table_name);
 }
@@ -2513,15 +2513,15 @@ void Frame_Glom::on_dialog_layout_print_hide()
 void Frame_Glom::on_dialog_tables_hide()
 {
   //If tables could have been added or removed, update the tables menu:
-  Document* document = dynamic_cast<Document*>(get_document());
+  auto document = dynamic_cast<Document*>(get_document());
   if(document)
   {
     // This is never true in client only mode, so we can as well save the
     // code size.
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-    if(document->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
+    if(document->get_userlevel() == AppState::userlevels::DEVELOPER)
     {
-      AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
+      auto pApp = dynamic_cast<AppWindow*>(get_app_window());
       if(pApp)
         pApp->fill_menu_tables();
 
@@ -2543,7 +2543,7 @@ void Frame_Glom::on_dialog_tables_hide()
 void Frame_Glom::on_notebook_data_switch_page(Gtk::Widget* /* page */)
 {
   //Refill this menu, because it depends on whether list or details are visible:
-  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
+  auto pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
     pApp->fill_menu_print_layouts(m_table_name);
 }
@@ -2561,7 +2561,7 @@ void Frame_Glom::on_notebook_data_record_selection_changed()
   if(!found_set.m_where_clause.empty())
     something_selected = true;
   
-  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
+  auto pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
     pApp->enable_menu_print_layouts_details(something_selected);  
 }
