@@ -29,13 +29,13 @@
 #include <glibmm/convert.h>
 #include <glibmm/miscutils.h>
 #include <glibmm/stringutils.h>
-#include <glibmm/regex.h>
 #include <glibmm/main.h>
 #include <glibmm/shell.h>
 #include <glibmm/i18n.h>
 
 #include <sstream> //For stringstream
 #include <iostream>
+#include <regex>
 
 #ifdef G_OS_WIN32
 # include <windows.h>
@@ -150,13 +150,13 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   if(m_database_directory_uri.empty())
   {
     std::cerr << G_STRFUNC << ": initialize: m_self_hosting_data_uri is empty." << std::endl;
-    return INITERROR_OTHER;
+    return InitErrors::OTHER;
   }
 
   if(initial_username.empty())
   {
     std::cerr << G_STRFUNC << ": PostgresSelfHosted::initialize(). Username was empty while attempting to create self-hosting database" << std::endl;
-    return INITERROR_OTHER;
+    return InitErrors::OTHER;
   }
 
   //Get the filepath of the directory that we should create:
@@ -164,7 +164,7 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   //std::cout << "debug: dbdir_uri=" << dbdir_uri << std::endl;
 
   if(file_exists_uri(dbdir_uri))
-    return INITERROR_DIRECTORY_ALREADY_EXISTS;
+    return InitErrors::DIRECTORY_ALREADY_EXISTS;
 
   const auto dbdir = Glib::filename_from_uri(dbdir_uri);
   //std::cout << "debug: dbdir=" << dbdir << std::endl;
@@ -175,7 +175,7 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   {
     std::cerr << G_STRFUNC << ": Couldn't create directory: " << dbdir << std::endl;
 
-    return INITERROR_COULD_NOT_CREATE_DIRECTORY;
+    return InitErrors::COULD_NOT_CREATE_DIRECTORY;
   }
 
   //Create the config directory:
@@ -184,7 +184,7 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   {
     std::cerr << G_STRFUNC << ": Couldn't create the config directory: " << dbdir << std::endl;
 
-    return INITERROR_COULD_NOT_CREATE_DIRECTORY;
+    return InitErrors::COULD_NOT_CREATE_DIRECTORY;
   }
 
   //Create these files: environment, pg_hba.conf, start.conf
@@ -196,7 +196,7 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   {
     std::cerr << G_STRFUNC << ": Couldn't create the data directory: " << dbdir << std::endl;
 
-    return INITERROR_COULD_NOT_CREATE_DIRECTORY;
+    return InitErrors::COULD_NOT_CREATE_DIRECTORY;
   }
 
   // initdb creates a new postgres database cluster:
@@ -222,111 +222,9 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   const auto temp_pwfile_removed = g_remove(temp_pwfile.c_str()); //Of course, we don't want this to stay around. It would be a security risk.
   g_assert(temp_pwfile_removed == 0);
 
-  return result ? INITERROR_NONE : INITERROR_COULD_NOT_START_SERVER;
+  return result ? InitErrors::NONE : InitErrors::COULD_NOT_START_SERVER;
 }
 
-Glib::ustring PostgresSelfHosted::get_postgresql_utils_version(const SlotProgress& slot_progress)
-{
-  Glib::ustring result;
-
-  const auto command = get_path_to_postgres_executable("pg_ctl") + " --version";
-
-  //The first command does not return, but the second command can check whether it succeeded:
-  std::string output;
-  const auto spawn_result = Glom::Spawn::execute_command_line_and_wait(command, slot_progress, output);
-  if(!spawn_result)
-  {
-    std::cerr << G_STRFUNC << ": Error while attempting to discover the pg_ctl version." << std::endl;
-    return result;
-  }
-
-  //Use a regex to get the version number:
-  Glib::RefPtr<Glib::Regex> regex;
-
-  //We want the characters at the end:
-  const gchar VERSION_REGEX[] = "pg_ctl \\(PostgreSQL\\) (.*)";
-
-  try
-  {
-    regex = Glib::Regex::create(VERSION_REGEX);
-  }
-  catch(const Glib::Error& ex)
-  {
-    std::cerr << G_STRFUNC << ": Glom: Glib::Regex::create() failed: " << ex.what() << std::endl;
-    return result;
-  }
-
-  if(!regex)
-    return result;
-
-  typedef std::vector<Glib::ustring> type_vec_strings;
-  const type_vec_strings vec = regex->split(output, Glib::REGEX_MATCH_NOTEMPTY);
-  //std::cout << "DEBUG: output == " << output << std::endl;
-  //std::cout << "DEBUG: vec.size() == " << vec.size() << std::endl;
-
-  // We get, for instance, "\n" and 8.4.1" and "\n".
-  for(const auto& str : vec)
-  {
-    if(!str.empty())
-      return str; //Found.
-  }
-
-  return result;
-}
-
-float PostgresSelfHosted::get_postgresql_utils_version_as_number(const SlotProgress& slot_progress)
-{
-  float result = 0;
-
-  const auto version_str = get_postgresql_utils_version(slot_progress);
-
-  Glib::RefPtr<Glib::Regex> regex;
-
-  //We want the characters at the end:
-  const gchar VERSION_REGEX[] = "^(\\d*)\\.(\\d*)";
-
-  try
-  {
-    regex = Glib::Regex::create(VERSION_REGEX);
-  }
-  catch(const Glib::Error& ex)
-  {
-    std::cerr << G_STRFUNC << ": Glom: Glib::Regex::create() failed: " << ex.what() << std::endl;
-    return result;
-  }
-
-  if(!regex)
-    return result;
-
-  const auto vec = regex->split(version_str, Glib::REGEX_MATCH_NOTEMPTY);
-  //std::cout << "DEBUG: str == " << version_str << std::endl;
-  //std::cout << "DEBUG: vec.size() == " << vec.size() << std::endl;
-
-  //We need to loop over the numbers because we get some "" items that we want to ignore:
-  guint count = 0; //We want 2 numbers.
-  for(const auto& str : vec)
-  {
-    //std::cout << "regex item: START" << *iter << "END" << std::endl;
-
-    if(str.empty())
-      continue;
-
-    const auto num = atoi(str.c_str());
-    if(count == 0)
-      result = num;
-    else if(count == 1)
-    {
-      result += (0.1 * num);
-      break;
-    }
-
-    ++count;
-  }
-
-  return result;
-}
-
-
 Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_progress, bool network_shared)
 {
   m_network_shared = network_shared;
@@ -338,7 +236,7 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
   if(get_self_hosting_active())
   {
     std::cerr << G_STRFUNC << ": Already started." << std::endl;
-    return STARTUPERROR_NONE; //Just do it once.
+    return StartupErrors::NONE; //Just do it once.
   }
 
   const auto dbdir_uri = m_database_directory_uri;
@@ -346,7 +244,7 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
   if(!(file_exists_uri(dbdir_uri)))
   {
     std::cerr << G_STRFUNC << ": The data directory could not be found: " << dbdir_uri << std::endl;
-    return STARTUPERROR_FAILED_NO_MAIN_DIRECTORY;
+    return StartupErrors::FAILED_NO_MAIN_DIRECTORY;
   }
 
   const auto dbdir = Glib::filename_from_uri(dbdir_uri);
@@ -362,12 +260,12 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
     {
       std::cerr << G_STRFUNC << ": There is no data, but there is backup data." << std::endl;
       //Let the caller convert the backup to real data and then try again:
-      return STARTUPERROR_FAILED_NO_DATA_HAS_BACKUP_DATA;
+      return StartupErrors::FAILED_NO_DATA_HAS_BACKUP_DATA;
     }
     else
     {
       std::cerr << G_STRFUNC << ": ConnectionPool::create_self_hosting(): The data sub-directory could not be found." << dbdir_data_uri << std::endl;
-      return STARTUPERROR_FAILED_NO_DATA;
+      return StartupErrors::FAILED_NO_DATA;
     }
   }
 
@@ -379,7 +277,7 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
   if(available_port == 0)
   {
     std::cerr << G_STRFUNC << ": No port was available between " << PORT_POSTGRESQL_SELF_HOSTED_START << " and " << PORT_POSTGRESQL_SELF_HOSTED_END << std::endl;
-    return STARTUPERROR_FAILED_NO_PORT_AVAILABLE;
+    return StartupErrors::FAILED_NO_PORT_AVAILABLE;
   }
 
   //TODO: Performance:
@@ -420,12 +318,12 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
   if(!result)
   {
     std::cerr << G_STRFUNC << ": Error while attempting to self-host a database." << std::endl;
-    return STARTUPERROR_FAILED_UNKNOWN_REASON;
+    return StartupErrors::FAILED_UNKNOWN_REASON;
   }
 
   m_port = available_port; //Remember it for later.
 
-  return STARTUPERROR_NONE;
+  return StartupErrors::NONE;
 }
 
 void PostgresSelfHosted::show_active_connections()
@@ -566,7 +464,7 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresSelfHosted::connect(const Glib::ust
 {
   if(!get_self_hosting_active())
   {
-    throw ExceptionConnection(ExceptionConnection::FAILURE_NO_BACKEND); //TODO: But there is a backend. It's just not ready.
+    throw ExceptionConnection(ExceptionConnection::failure_type::NO_BACKEND); //TODO: But there is a backend. It's just not ready.
   }
 
   Glib::RefPtr<Gnome::Gda::Connection> result;
@@ -582,7 +480,7 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresSelfHosted::connect(const Glib::ust
     }
     catch(const ExceptionConnection& ex)
     {
-      if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
+      if(ex.get_failure_type() == ExceptionConnection::failure_type::NO_SERVER)
       {
         //It must be using a default password, so any failure would not be due to a wrong password.
         //However, pg_ctl sometimes reports success before it is really ready to let us connect,
