@@ -26,7 +26,7 @@ namespace Glom
 
 LayoutItem_Text::LayoutItem_Text()
 {
-  m_translatable_item_type = TRANSLATABLE_TYPE_TEXTOBJECT;
+  m_translatable_item_type = enumTranslatableItemType::TEXTOBJECT;
   m_text = std::make_shared<StaticText>(); //TODO: Why use a smartpointer?
 }
 
@@ -35,7 +35,7 @@ LayoutItem_Text::LayoutItem_Text(const LayoutItem_Text& src)
 {
   //Copy the underlying TranslatableItem, not the std::shared_ptr to it:
   const auto src_item = *(src.m_text);
-  m_text = std::shared_ptr<StaticText>(new StaticText(src_item));
+  m_text = std::make_shared<StaticText>(src_item);
 }
 
 LayoutItem_Text::~LayoutItem_Text()
@@ -62,7 +62,7 @@ LayoutItem_Text& LayoutItem_Text::operator=(const LayoutItem_Text& src)
 
   //Copy the underlying TranslatableItem, not the shardptr to it:
   const auto src_item = *(src.m_text);
-  m_text = std::shared_ptr<StaticText>(new StaticText(src_item));
+  m_text = std::make_shared<StaticText>(src_item);
 
   return *this;
 }
