@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_MODE_DATA_COMBO_H
@@ -53,15 +53,15 @@ public:
   virtual void set_choices_fixed(const Formatting::type_list_values& list_values, bool restricted = false);
 
   //This creates a db-based tree model, with appropriate cell renderers:
-  virtual void set_choices_related(const Document* document, const sharedptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value);
+  virtual void set_choices_related(const Document* document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value);
 
-  virtual void set_read_only(bool read_only = true);
+  virtual void set_read_only(bool read_only = true) override;
 
   /** Set the text from a Gnome::Gda::Value.
    */
-  virtual void set_value(const Gnome::Gda::Value& value);
+  virtual void set_value(const Gnome::Gda::Value& value) override;
 
-  virtual Gnome::Gda::Value get_value() const;
+  virtual Gnome::Gda::Value get_value() const override;
 
 private:
 
@@ -69,15 +69,15 @@ private:
 
   // Note that this is a normal signal handler when glibmm was complied
   // without default signal handlers
-  virtual void on_changed(); //From Gtk::ComboBox
+  virtual void on_changed() override; //From Gtk::ComboBox
 
-  virtual void check_for_change();
+  void check_for_change();
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual bool on_button_press_event(GdkEventButton *event);
+  virtual bool on_button_press_event(GdkEventButton *event) override;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual AppWindow* get_appwindow() const;
+  virtual AppWindow* get_appwindow() const override;
 
 
   Gnome::Gda::Value m_old_value; //TODO: Only useful for navigation, which currently has no implementation.
