@@ -80,36 +80,33 @@ public:
    * @param layoutitem_field The layout item that describes this field,
    * @param table_name The table on which this layout appears.
    */
-  void add_field(const sharedptr<LayoutItem_Field>& layoutitem_field, const Glib::ustring& table_name);
+  void add_field(const std::shared_ptr<LayoutItem_Field>& layoutitem_field, const Glib::ustring& table_name);
 
   void remove_field(const Glib::ustring& id);
 
-  typedef std::map<int, Field> type_map_field_sequence;
-  //virtual void add_group(const Glib::ustring& group_name, const Glib::ustring& group_title, const type_map_field_sequence& fields);
-
-  void add_layout_item(const sharedptr<LayoutItem>& item);
+  void add_layout_item(const std::shared_ptr<LayoutItem>& item);
 
   /**
    * @param with_indent Pass true for top-level groups, to avoid wasting extra space with an unnecessary indent.
    */
-  void add_layout_group(const sharedptr<LayoutGroup>& group, bool with_indent = true);
+  void add_layout_group(const std::shared_ptr<LayoutGroup>& group, bool with_indent = true);
 
-  void set_field_editable(const sharedptr<const LayoutItem_Field>& field, bool editable = true);
+  void set_field_editable(const std::shared_ptr<const LayoutItem_Field>& field, bool editable = true);
 
-  Gnome::Gda::Value get_field_value(const sharedptr<const LayoutItem_Field>& field) const;
+  Gnome::Gda::Value get_field_value(const std::shared_ptr<const LayoutItem_Field>& field) const;
 
   /** Set the displayed @a value in any instances of the specified @a field.
    */
-  void set_field_value(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
+  void set_field_value(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
 
   /** Set the displayed @a value in any instances of the field other than the specified @a layout_field.
    */
-  void set_other_field_value(const sharedptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& value);
+  void set_other_field_value(const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& value);
 
   /** Refresh the list of related records in choice combo boxes, 
    * in any instance of the specified field.
    */
-  void update_choices(const sharedptr<const LayoutItem_Field>& field);
+  void update_choices(const std::shared_ptr<const LayoutItem_Field>& field);
 
   typedef std::list<Gtk::Widget*> type_list_widgets;
   typedef std::list<const Gtk::Widget*> type_list_const_widgets;
@@ -140,27 +137,27 @@ public:
    * or a new relationship for a portal.
    */
   void get_layout_groups(Document::type_list_layout_groups& groups);
-  sharedptr<LayoutGroup> get_layout_group();
+  std::shared_ptr<LayoutGroup> get_layout_group();
   
   void set_enable_drag_and_drop(bool enabled = true);
 
   /** For instance,
-   * void on_flowtable_field_edited(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
+   * void on_flowtable_field_edited(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
    */
-  typedef sigc::signal<void, const sharedptr<const LayoutItem_Field>&, const Gnome::Gda::Value&> type_signal_field_edited;
+  typedef sigc::signal<void, const std::shared_ptr<const LayoutItem_Field>&, const Gnome::Gda::Value&> type_signal_field_edited;
   type_signal_field_edited signal_field_edited();
 
   /** For instance,
-   * void on_flowtable_field_choices_changed(const sharedptr<const LayoutItem_Field>& field);
+   * void on_flowtable_field_choices_changed(const std::shared_ptr<const LayoutItem_Field>& field);
    */
-  typedef sigc::signal<void, const sharedptr<const LayoutItem_Field>&> type_signal_field_choices_changed;
+  typedef sigc::signal<void, const std::shared_ptr<const LayoutItem_Field>&> type_signal_field_choices_changed;
   type_signal_field_choices_changed signal_field_choices_changed();
 
 
   /** For instance,
-   * void on_flowtable_field_open_details_requested(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
+   * void on_flowtable_field_open_details_requested(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
    */
-  typedef sigc::signal<void, const sharedptr<const LayoutItem_Field>&, const Gnome::Gda::Value&> type_signal_field_open_details_requested;
+  typedef sigc::signal<void, const std::shared_ptr<const LayoutItem_Field>&, const Gnome::Gda::Value&> type_signal_field_open_details_requested;
   type_signal_field_open_details_requested signal_field_open_details_requested();
 
   /** For instance,
@@ -176,30 +173,30 @@ public:
   type_signal_requested_related_details signal_requested_related_details();
 
  /** For instance,
-   * void on_script_button_clicked(const sharedptr<LayoutItem_Button>& layout_item>);
+   * void on_script_button_clicked(const std::shared_ptr<LayoutItem_Button>& layout_item>);
    */
-  typedef sigc::signal<void, const sharedptr<LayoutItem_Button>&> type_signal_script_button_clicked;
+  typedef sigc::signal<void, const std::shared_ptr<LayoutItem_Button>&> type_signal_script_button_clicked;
   type_signal_script_button_clicked signal_script_button_clicked();
 
 private:
 
-  void set_field_value(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value, bool set_specified_field_layout);
+  void set_field_value(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value, bool set_specified_field_layout);
 
   // If include_item is set, then the output list will contain field's widget,
   // otherwise not.
-  type_list_widgets get_field(const sharedptr<const LayoutItem_Field>& field, bool include_item);
-  type_list_const_widgets get_field(const sharedptr<const LayoutItem_Field>& field, bool include_item) const;
+  type_list_widgets get_field(const std::shared_ptr<const LayoutItem_Field>& field, bool include_item);
+  type_list_const_widgets get_field(const std::shared_ptr<const LayoutItem_Field>& field, bool include_item) const;
 
   typedef std::list<Box_Data_Portal*> type_portals;
 
   /// Get portals whose relationships have @a from_key as the from_key.
-  type_portals get_portals(const sharedptr<const LayoutItem_Field>& from_key);
+  type_portals get_portals(const std::shared_ptr<const LayoutItem_Field>& from_key);
 
 
   typedef std::list<DataWidgetChildren::ComboChoices*> type_choice_widgets;
 
   /// Get choice widgets with !show_all relationships that have @a from_key as the from_key.
-  type_choice_widgets get_choice_widgets(const sharedptr<const LayoutItem_Field>& from_key);
+  type_choice_widgets get_choice_widgets(const std::shared_ptr<const LayoutItem_Field>& from_key);
 
   /** Examine this flow table and all child flow tables, discovering which
    * has the most columns.
@@ -208,11 +205,11 @@ private:
 
   //int get_suitable_width(Field::glom_field_type field_type);
 
-  void on_entry_edited(const Gnome::Gda::Value& value, const sharedptr<const LayoutItem_Field> field);
-  void on_entry_choices_changed(const sharedptr<const LayoutItem_Field> field);
-  void on_entry_open_details_requested(const Gnome::Gda::Value& value, const sharedptr<const LayoutItem_Field> field);
+  void on_entry_edited(const Gnome::Gda::Value& value, const std::shared_ptr<const LayoutItem_Field> field);
+  void on_entry_choices_changed(const std::shared_ptr<const LayoutItem_Field> field);
+  void on_entry_open_details_requested(const Gnome::Gda::Value& value, const std::shared_ptr<const LayoutItem_Field> field);
 
-  void on_script_button_clicked(const sharedptr<LayoutItem_Button>& layout_item);
+  void on_script_button_clicked(const std::shared_ptr<LayoutItem_Button>& layout_item);
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_datawidget_layout_item_added(LayoutWidgetBase::enumType item_type, DataWidget* pDataWidget);
@@ -224,7 +221,7 @@ private:
   public:
     Info();
 
-    sharedptr<const LayoutItem_Field> m_field; //Store the field information so we know the title, ID, and type.
+    std::shared_ptr<const LayoutItem_Field> m_field; //Store the field information so we know the title, ID, and type.
 
     Gtk::Widget* m_first;
     Gtk::EventBox* m_first_eventbox; //The label is often inside an eventbox.
@@ -247,22 +244,22 @@ private:
   typedef std::list< LayoutWidgetBase* > type_list_layoutwidgets;
   type_list_layoutwidgets m_list_layoutwidgets;
 
-  void add_button(const sharedptr<LayoutItem_Button>& layoutitem_button, const Glib::ustring& table_name);
-  void add_textobject(const sharedptr<LayoutItem_Text>& layoutitem_text, const Glib::ustring& table_name);
-  void add_imageobject(const sharedptr<LayoutItem_Image>& layoutitem_image, const Glib::ustring& table_name);
+  void add_button(const std::shared_ptr<LayoutItem_Button>& layoutitem_button, const Glib::ustring& table_name);
+  void add_textobject(const std::shared_ptr<LayoutItem_Text>& layoutitem_text, const Glib::ustring& table_name);
+  void add_imageobject(const std::shared_ptr<LayoutItem_Image>& layoutitem_image, const Glib::ustring& table_name);
 
   void add_layoutwidgetbase(LayoutWidgetBase* layout_widget);
-  void add_layout_notebook(const sharedptr<LayoutItem_Notebook>& notebook);
-  void add_layout_portal(const sharedptr<LayoutItem_Portal>& portal);
+  void add_layout_notebook(const std::shared_ptr<LayoutItem_Notebook>& notebook);
+  void add_layout_portal(const std::shared_ptr<LayoutItem_Portal>& portal);
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 
-  sharedptr<LayoutItem_Portal> get_portal_relationship();
+  std::shared_ptr<LayoutItem_Portal> get_portal_relationship();
 
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  Box_Data_List_Related* create_related(const sharedptr<LayoutItem_Portal>& portal, bool show_title = true);
-  Box_Data_Calendar_Related* create_related_calendar(const sharedptr<LayoutItem_CalendarPortal>& portal, bool show_title = true);
+  Box_Data_List_Related* create_related(const std::shared_ptr<LayoutItem_Portal>& portal, bool show_title = true);
+  Box_Data_Calendar_Related* create_related_calendar(const std::shared_ptr<LayoutItem_CalendarPortal>& portal, bool show_title = true);
 
   Gtk::Bin* m_placeholder;
 
@@ -286,7 +283,7 @@ private:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual void on_menu_properties_activate();
   virtual void on_menu_delete_activate(); // override this to add a dialog box
-  virtual bool on_button_press_event(GdkEventButton *event);
+  virtual bool on_button_press_event(GdkEventButton *event) override;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 };
 
