@@ -64,7 +64,7 @@ void Box_DB_Table_Definition::init()
 
   m_colTitle = m_AddDel.add_column(_("Title"));
 
-  m_colType = m_AddDel.add_column(_("Type"), AddDelColumnInfo::STYLE_Choices);
+  m_colType = m_AddDel.add_column(_("Type"), AddDelColumnInfo::enumStyles::Choices);
   m_AddDel.set_column_width(m_colType, 100); //TODO: Auto-size columns.
 
 
@@ -84,8 +84,8 @@ void Box_DB_Table_Definition::init()
 
   m_AddDel.set_column_choices(m_colType, vecTypes);
 
-  m_colUnique = m_AddDel.add_column("Unique", AddDelColumnInfo::STYLE_Boolean);
-  m_colPrimaryKey = m_AddDel.add_column("Primary Key", AddDelColumnInfo::STYLE_Boolean);
+  m_colUnique = m_AddDel.add_column("Unique", AddDelColumnInfo::enumStyles::Boolean);
+  m_colPrimaryKey = m_AddDel.add_column("Primary Key", AddDelColumnInfo::enumStyles::Boolean);
 
   //Connect signals:
   m_AddDel.signal_user_added().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_adddel_add));
@@ -123,7 +123,7 @@ void Box_DB_Table_Definition::fill_field_row(const Gtk::TreeModel::iterator& ite
   m_AddDel.set_value(iter, m_colTitle, title);
 
   //Type:
-  //Field::glom_field_type fieldType = Field::get_glom_type_for_gda_type(field->get_field_info()->get_g_type()); //Could be TYPE_INVALID if the gda type is not one of ours.
+  //Field::glom_field_type fieldType = Field::get_glom_type_for_gda_type(field->get_field_info()->get_g_type()); //Could be INVALID if the gda type is not one of ours.
   // TODO: Why was this done by converting the field's gtype to a glom type
   // instead of using the glom type directly? This breaks numerical types in
   // sqlite which we store as double.
@@ -191,18 +191,18 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
   Glib::ustring name = m_AddDel.get_value(row, m_colName);
   if(!name.empty())
   {
-    std::shared_ptr<Field> field(new Field());
+    auto field = std::make_shared<Field>();
     field->set_name(name);
     field->set_title( Utils::title_from_string(name) , AppWindow::get_current_locale()); //Start with a title that might be useful.
-    field->set_glom_type(Field::TYPE_NUMERIC);
+    field->set_glom_type(Field::glom_field_type::NUMERIC);
 
     Glib::RefPtr<Gnome::Gda::Column> field_info = field->get_field_info();
-    field_info->set_g_type( Field::get_gda_type_for_glom_type(Field::TYPE_NUMERIC) );
+    field_info->set_g_type( Field::get_gda_type_for_glom_type(Field::glom_field_type::NUMERIC) );
     field->set_field_info(field_info);
 
     //TODO: Warn about a delay before actually doing this when the backend
     //needs to recreate the whole table.
-    const auto bTest = DbUtils::add_column(m_table_name, field, get_app_window()); //TODO: Get schema type for Field::TYPE_NUMERIC
+    const auto bTest = DbUtils::add_column(m_table_name, field, get_app_window()); //TODO: Get schema type for Field::glom_field_type::NUMERIC
     if(bTest)
     {
       //Store the generated title in the document:
@@ -212,10 +212,10 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
       // unnecessary extra stuff just to get the field added into the
       // document:
 
-      Document* pDoc = static_cast<Document*>(get_document());
+      auto pDoc = static_cast<Document*>(get_document());
       if(pDoc)
       {
-        std::cout << field->get_glom_type() << std::endl;
+        std::cout << Utils::to_utype(field->get_glom_type()) << std::endl;
         Document::type_vec_fields vecFields = pDoc->get_table_fields(m_table_name);
         vecFields.push_back(field);
         pDoc->set_table_fields(m_table_name, vecFields);
@@ -275,7 +275,7 @@ bool Box_DB_Table_Definition::check_field_change(const std::shared_ptr<const Fie
 {
   bool result = true; //Tells the caller whether to continue.
 
-  Gtk::Window* parent_window = get_app_window();
+  auto parent_window = get_app_window();
 
   //Warn about a long slow recalculation, and offer the chance to cancel it:
   if(field_new->get_has_calculation())
@@ -296,7 +296,7 @@ bool Box_DB_Table_Definition::check_field_change(const std::shared_ptr<const Fie
 
   //If we are changing a non-glom type:
   //Refuse to edit field definitions that were not created by glom:
-  if(field_old->get_glom_type() == Field::TYPE_INVALID)
+  if(field_old->get_glom_type() == Field::glom_field_type::INVALID)
   {
     UiUtils::show_ok_dialog(_("Invalid database structure"),
       _("This database field was created or edited outside of Glom. It has a data type that is not supported by Glom. Your system administrator may be able to correct this."), parent_window, Gtk::MESSAGE_ERROR);
@@ -364,7 +364,7 @@ bool Box_DB_Table_Definition::check_field_change(const std::shared_ptr<const Fie
 void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint /* col */)
 {
   //Get old field definition:
-  Document* pDoc = static_cast<Document*>(get_document());
+  auto pDoc = static_cast<Document*>(get_document());
   if(pDoc)
   {
     const auto strFieldNameBeingEdited = m_AddDel.get_value_key(row);
@@ -373,7 +373,7 @@ void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator&
     m_Field_BeingEdited = constfield;
 
     //Get DB field info: (TODO: This might be unnecessary).
-    type_vec_fields::const_iterator iterFind = std::find_if( m_vecFields.begin(), m_vecFields.end(), predicate_FieldHasName<Field>(strFieldNameBeingEdited) );
+    type_vec_fields::const_iterator iterFind = find_if_same_name(m_vecFields, strFieldNameBeingEdited);
     if(iterFind == m_vecFields.end()) //If it was not found:
       std::cerr << G_STRFUNC << ": field not found: " << strFieldNameBeingEdited << std::endl;
     else
@@ -417,7 +417,7 @@ void Box_DB_Table_Definition::on_adddel_edit(const Gtk::TreeModel::iterator& row
 
   //m_dialog_field_definition->set_modified(false); //Disable [Apply] at start.
 
-  Gtk::Window* parent_window = get_app_window();
+  auto parent_window = get_app_window();
   if(parent_window)
     m_dialog_field_definition->set_transient_for(*parent_window);
 
@@ -433,7 +433,7 @@ void Box_DB_Table_Definition::on_adddel_extra(const Gtk::TreeModel::iterator& ro
 
   //m_dialog_field_definition->set_modified(false); //Disable [Apply] at start.
 
-  Gtk::Window* parent_window = get_app_window();
+  auto parent_window = get_app_window();
   if(parent_window)
     m_dialog_default_formatting->set_transient_for(*parent_window);
 
@@ -449,11 +449,11 @@ std::shared_ptr<Field> Box_DB_Table_Definition::get_field_definition(const Gtk::
   const auto strFieldNameBeforeEdit = m_AddDel.get_value_key(row);
 
   //Glom field definition:
-  Document* pDoc = static_cast<Document*>(get_document());
+  auto pDoc = static_cast<Document*>(get_document());
   if(pDoc)
   {
     Document::type_vec_fields vecFields= pDoc->get_table_fields(m_table_name);
-    auto iterFind = std::find_if( vecFields.begin(), vecFields.end(), predicate_FieldHasName<Field>(strFieldNameBeforeEdit) );
+    auto iterFind = find_if_same_name(vecFields, strFieldNameBeforeEdit);
 
     if((iterFind != vecFields.end()) && (*iterFind)) //If it was found:
     {
@@ -590,7 +590,7 @@ std::shared_ptr<Field> Box_DB_Table_Definition::change_definition(const std::sha
 
     //Forget the remembered currently-viewed primary key value, 
     //because it will be useless with a different field as the primary key, or with no field as primary key:
-    Document* document = get_document();
+    auto document = get_document();
     document->forget_layout_record_viewed(m_table_name);
   }
 
@@ -618,7 +618,7 @@ std::shared_ptr<Field> Box_DB_Table_Definition::change_definition(const std::sha
   }
 
   //Extra Glom field definitions:
-  Document* pDoc = static_cast<Document*>(get_document());
+  auto pDoc = static_cast<Document*>(get_document());
   if(pDoc)
   {
     //Get Table's fields:
@@ -628,7 +628,7 @@ std::shared_ptr<Field> Box_DB_Table_Definition::change_definition(const std::sha
     {
       //Find old field:
       const auto field_name_old = old_fields[i]->get_name();
-      auto iterFind = std::find_if( vecFields.begin(), vecFields.end(), predicate_FieldHasName<Field>(field_name_old) );
+      auto iterFind = find_if_same_name(vecFields, field_name_old);
       if(iterFind != vecFields.end()) //If it was found:
       {
         //Change it to the new Fields's value:
