@@ -32,15 +32,15 @@ const bool Dialog_FieldLayout::glade_developer(true);
 
 Dialog_FieldLayout::Dialog_FieldLayout(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
-  m_label_field_name(0),
-  m_checkbutton_editable(0),
-  m_radiobutton_title_default(0),
-  m_label_title_default(0),
-  m_radiobutton_title_custom(0),
-  m_entry_title_custom(0),
-  m_box_formatting_placeholder(0),
-  m_radiobutton_custom_formatting(0),
-  m_box_formatting(0)
+  m_label_field_name(nullptr),
+  m_checkbutton_editable(nullptr),
+  m_radiobutton_title_default(nullptr),
+  m_label_title_default(nullptr),
+  m_radiobutton_title_custom(nullptr),
+  m_entry_title_custom(nullptr),
+  m_box_formatting_placeholder(nullptr),
+  m_radiobutton_custom_formatting(nullptr),
+  m_box_formatting(nullptr)
 {
   builder->get_widget("label_field_name", m_label_field_name);
   builder->get_widget("checkbutton_editable", m_checkbutton_editable);
@@ -68,7 +68,7 @@ Dialog_FieldLayout::~Dialog_FieldLayout()
   remove_view(m_box_formatting);
 }
 
-void Dialog_FieldLayout::set_field(const sharedptr<const LayoutItem_Field>& field, const Glib::ustring& table_name, bool show_editable_options)
+void Dialog_FieldLayout::set_field(const std::shared_ptr<const LayoutItem_Field>& field, const Glib::ustring& table_name, bool show_editable_options)
 {
   m_layout_item = glom_sharedptr_clone(field);
 
@@ -79,7 +79,7 @@ void Dialog_FieldLayout::set_field(const sharedptr<const LayoutItem_Field>& fiel
   m_checkbutton_editable->set_active( field->get_editable() );
 
   //Calculated fields can never be edited:
-  sharedptr<const Field> field_details = field->get_full_field_details();
+  std::shared_ptr<const Field> field_details = field->get_full_field_details();
   const bool editable_allowed = field_details && !field_details->get_has_calculation();
   m_checkbutton_editable->set_sensitive(editable_allowed);
 
@@ -104,14 +104,14 @@ void Dialog_FieldLayout::set_field(const sharedptr<const LayoutItem_Field>& fiel
   enforce_constraints();
 }
 
-sharedptr<LayoutItem_Field> Dialog_FieldLayout::get_field_chosen() const
+std::shared_ptr<LayoutItem_Field> Dialog_FieldLayout::get_field_chosen() const
 {
   m_layout_item->set_editable( m_checkbutton_editable->get_active() );
 
   m_layout_item->set_formatting_use_default( !m_radiobutton_custom_formatting->get_active() );
   m_box_formatting->get_formatting(m_layout_item->m_formatting);
 
-  sharedptr<CustomTitle> title_custom = sharedptr<CustomTitle>::create();
+  std::shared_ptr<CustomTitle> title_custom = std::make_shared<CustomTitle>();
   title_custom->set_use_custom_title(m_radiobutton_title_custom->get_active()); //For instance, tell it to really use a blank title.
   title_custom->set_title(m_entry_title_custom->get_text(), AppWindow::get_current_locale());
 
@@ -128,7 +128,7 @@ void Dialog_FieldLayout::on_radiobutton_custom_formatting()
 void Dialog_FieldLayout::enforce_constraints()
 {
   //Enable/Disable the custom formatting widgets:
-  const bool custom = m_radiobutton_custom_formatting->get_active();
+  const auto custom = m_radiobutton_custom_formatting->get_active();
   m_box_formatting->set_sensitive(custom);
 }
 
