@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <glom/print_layout/printoperation_printlayout.h>
@@ -21,7 +21,7 @@ namespace Glom
 {
 
 PrintOperationPrintLayout::PrintOperationPrintLayout()
-: m_canvas(0)
+: m_canvas(nullptr)
 {
   set_unit(Gtk::UNIT_MM);
   set_use_full_page(true); //Because we show the margins on our canvas.
@@ -80,7 +80,7 @@ void PrintOperationPrintLayout::on_draw_page(
 
 
   //Render the canvas onto the cairo context:
-  const Goocanvas::Bounds bounds = m_canvas->get_page_bounds(page_nr);
+  const auto bounds = m_canvas->get_page_bounds(page_nr);
   //std::cout << G_STRFUNC << ": page_nr=" << page_nr << ", bounds: x1=" << bounds.get_x1() << ", y1=" << bounds.get_y1() << ", x2=" << bounds.get_x2() << ", y2=" << bounds.get_y2() << std::endl;
 
   //Shift the renderer context up into the page:
