@@ -54,7 +54,7 @@ void glom_execute_python_function_implementation(const Glib::ustring& func_impl,
   const type_map_fields& field_values,
   const Document* pDocument,
   const Glib::ustring& table_name,
-  const sharedptr<const Field>& key_field,
+  const std::shared_ptr<const Field>& key_field,
   const Gnome::Gda::Value& key_field_value,
   const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection,
   const PythonUICallbacks& callbacks,
@@ -69,7 +69,7 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
   const type_map_fields& field_values,
   const Document* pDocument,
   const Glib::ustring& table_name,
-  const sharedptr<const Field>& key_field,
+  const std::shared_ptr<const Field>& key_field,
   const Gnome::Gda::Value& key_field_value,
   const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection,
   Glib::ustring& error_message);
