@@ -33,9 +33,9 @@ void evaluate_function_implementation(const Glib::ustring& func_impl)
 
   typedef std::list<Glib::ustring> type_listStrings;
   type_listStrings listStrings = ustring_tokenize(func_impl, "\n", -1);
-  for(type_listStrings::const_iterator iter = listStrings.begin(); iter != listStrings.end(); ++iter)
+  for(const auto& item : listStrings)
   {
-    func_def += "  " + *iter + '\n';
+    func_def += "  " + item + '\n';
   }
 
   //Indent the function implementation (required by python syntax):
@@ -52,31 +52,31 @@ void evaluate_function_implementation(const Glib::ustring& func_impl)
   PyObject* pDict = PyModule_GetDict(pMain);
 
   //Create the function definition:
-  PyObject* pyValue = PyRun_String(func_def.c_str(), Py_file_input, pDict, pDict);
-  if(pyValue)
+  PyObject* pyValueFunc = PyRun_String(func_def.c_str(), Py_file_input, pDict, pDict);
+  if(pyValueFunc)
   {
-    Py_DECREF(pyValue);
-    pyValue = 0;
+    Py_DECREF(pyValueFunc);
+    pyValueFunc = nullptr;
   }
 
   //Call the function:
   {
     Glib::ustring call_func = "glom_calc_field_value()";
-    PyObject* pyValue = PyRun_String(call_func.c_str(), Py_eval_input, pDict, pDict);
-    if(!pyValue)
+    PyObject* pyValueCall = PyRun_String(call_func.c_str(), Py_eval_input, pDict, pDict);
+    if(!pyValueCall)
     {
-      g_warning("pyValue was null");
+      g_warning("pyValueCall was null");
       PyErr_Print();
     }
     else
     {
-      PyObject* pyStringObject = PyObject_Str(pyValue);
+      PyObject* pyStringObject = PyObject_Str(pyValueCall);
       if(pyStringObject)
       {
         if(PyUnicode_Check(pyStringObject))
         {
           PyObject* pyStr = PyUnicode_AsEncodedString(pyStringObject, "utf-8", "Error ~");
-          const char* pchResult = PyBytes_AS_STRING(pyStr);
+          const auto pchResult = PyBytes_AS_STRING(pyStr);
           if(pchResult)
           {
             g_warning("result is %s", pchResult);
@@ -91,7 +91,8 @@ void evaluate_function_implementation(const Glib::ustring& func_impl)
       else
         g_warning("pyStringObject is null");
 
-      Py_DECREF(pyValue);
+      Py_DECREF(pyValueCall);
+      pyValueCall = nullptr;
     }
   }
 
