@@ -64,7 +64,7 @@ void DialogImageLoadProgress::load(const Glib::ustring& uri)
   g_assert(!m_data.get());
 
   m_data.reset(new GdaBinary);
-  m_data->data = 0;
+  m_data->data = nullptr;
   m_data->binary_length = 0;
 
   m_file = Gio::File::create_for_uri(uri);
@@ -120,7 +120,7 @@ void DialogImageLoadProgress::on_stream_read(const Glib::RefPtr<Gio::AsyncResult
 {
   try
   {
-    const gssize size = m_stream->read_finish(result);
+    const auto size = m_stream->read_finish(result);
     g_assert(size >= 0); // Would have thrown an exception otherwise
     
     // Cannot read more data than there is available in the file:
@@ -165,7 +165,7 @@ void DialogImageLoadProgress::error(const Glib::ustring& error_message)
   response(Gtk::RESPONSE_REJECT);
 }
 
-std::auto_ptr<GdaBinary> DialogImageLoadProgress::get_image_data()
+std::shared_ptr<GdaBinary> DialogImageLoadProgress::get_image_data()
 {
   return m_data;
 }
