@@ -80,35 +80,35 @@ void Dialog_Properties::widget_connect_changed_signal(Gtk::Widget* widget)
     return;
   }
 
-  Gtk::ComboBox* pCombo = dynamic_cast<Gtk::ComboBox*>(widget);
+  auto pCombo = dynamic_cast<Gtk::ComboBox*>(widget);
   if(pCombo) //If it is actually a Combo:
   {
     pCombo->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Properties::on_anything_changed));
   }
   else
   {
-    Gtk::Entry* pEntry = dynamic_cast<Gtk::Entry*>(widget);
+    auto pEntry = dynamic_cast<Gtk::Entry*>(widget);
     if(pEntry) //If it is actually an Entry:
     {
       pEntry->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Properties::on_anything_changed));
     }
     else
     {
-      Gtk::ToggleButton* pToggleButton = dynamic_cast<Gtk::ToggleButton*>(widget);
+      auto pToggleButton = dynamic_cast<Gtk::ToggleButton*>(widget);
       if(pToggleButton)
       {
         pToggleButton->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_Properties::on_anything_changed) );
       }
       else
       {
-        Gtk::TextView* pTextView = dynamic_cast<Gtk::TextView*>(widget);
+        auto pTextView = dynamic_cast<Gtk::TextView*>(widget);
         if(pTextView)
         {
           pTextView->get_buffer()->signal_changed().connect( sigc::mem_fun(*this, &Dialog_Properties::on_anything_changed) );
         }
         else
         {
-          AddDel* pAddDel = dynamic_cast<AddDel*>(widget);
+          auto pAddDel = dynamic_cast<AddDel*>(widget);
           if(pAddDel)
           {
             pAddDel->signal_user_changed().connect( sigc::mem_fun(*this, &Dialog_Properties::on_adddel_user_changed) );
@@ -152,7 +152,7 @@ void Dialog_Properties::on_foreach_connect(Gtk::Widget& widget)
   widget_connect_changed_signal(&widget); //Connect the appropriate signal
 
   //Recurse through children:
-  Gtk::Container* pContainer = dynamic_cast<Gtk::Container*>(&widget);
+  auto pContainer = dynamic_cast<Gtk::Container*>(&widget);
   if(pContainer)
   {
     pContainer->foreach( sigc::mem_fun(*this, &Dialog_Properties::on_foreach_connect)); //recursive
