@@ -78,30 +78,30 @@ void FileChooserDialog_SaveExtras::create_child_widgets()
   m_label_extra_message.set_halign(Gtk::ALIGN_START);
   m_label_extra_message.set_valign(Gtk::ALIGN_CENTER);
 
-  Gtk::Frame* frame = Gtk::manage(new Gtk::Frame());
-  Gtk::Label* frame_label = Gtk::manage(new Gtk::Label());
+  auto frame = Gtk::manage(new Gtk::Frame());
+  auto frame_label = Gtk::manage(new Gtk::Label());
   frame_label->set_markup(UiUtils::bold_message(_("New Database")));
   frame_label->show();
   frame->set_label_widget(*frame_label);
   frame->set_shadow_type(Gtk::SHADOW_NONE);
   frame->show();
 
-  Gtk::Box* vbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, UiUtils::DEFAULT_SPACING_SMALL));
-  vbox->set_margin_start(UiUtils::DEFAULT_SPACING_LARGE);
-  vbox->set_margin_top(UiUtils::DEFAULT_SPACING_SMALL);
+  auto vbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, Utils::to_utype(UiUtils::DefaultSpacings::SMALL)));
+  vbox->set_margin_start(Utils::to_utype(UiUtils::DefaultSpacings::LARGE));
+  vbox->set_margin_top(Utils::to_utype(UiUtils::DefaultSpacings::SMALL));
   frame->add(*vbox);
   vbox->show();
 
   vbox->pack_start(m_label_extra_message); /* For instance, an extra hint when saving from an example, saying that a new file must be saved. */
 
-  Gtk::Label* label_newdb = Gtk::manage(new Gtk::Label(_("Please choose a human-readable title for the new database. You can change this later in the database properties. It may contain any characters.")));
+  auto label_newdb = Gtk::manage(new Gtk::Label(_("Please choose a human-readable title for the new database. You can change this later in the database properties. It may contain any characters.")));
   vbox->pack_start(*label_newdb);
   label_newdb->set_halign(Gtk::ALIGN_START);
   label_newdb->set_valign(Gtk::ALIGN_CENTER);
   label_newdb->show();
 
-  Gtk::Box* box_label = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, UiUtils::DEFAULT_SPACING_LARGE));
-  Gtk::Label* label_title = Gtk::manage(new Gtk::Label(_("_Title:"), true));
+  auto box_label = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, Utils::to_utype(UiUtils::DefaultSpacings::LARGE)));
+  auto label_title = Gtk::manage(new Gtk::Label(_("_Title:"), true));
   box_label->pack_start(*label_title, Gtk::PACK_SHRINK);
   label_title->show();
   box_label->pack_start(m_entry_title);
@@ -177,25 +177,25 @@ void FileChooserDialog_SaveExtras::set_extra_newdb_hosting_mode(Document::Hostin
   switch(mode)
   {
 #ifdef GLOM_ENABLE_POSTGRESQL
-  case Document::HOSTING_MODE_POSTGRES_CENTRAL:
+  case Document::HostingMode::POSTGRES_CENTRAL:
     m_radiobutton_server_postgres_central.set_active();
     break;
-  case Document::HOSTING_MODE_POSTGRES_SELF:
+  case Document::HostingMode::POSTGRES_SELF:
     m_radiobutton_server_postgres_selfhosted.set_active();
     break;
 #endif //GLOM_ENABLE_POSTGRESQL
 
 #ifdef GLOM_ENABLE_SQLITE
-  case Document::HOSTING_MODE_SQLITE:
+  case Document::HostingMode::SQLITE:
     m_radiobutton_server_sqlite.set_active();
     break;
 #endif //GLOM_ENABLE_SQLITE
 
 #ifdef GLOM_ENABLE_MYSQL
-  case Document::HOSTING_MODE_MYSQL_CENTRAL:
+  case Document::HostingMode::MYSQL_CENTRAL:
     m_radiobutton_server_mysql_central.set_active();
     break;
-  case Document::HOSTING_MODE_MYSQL_SELF:
+  case Document::HostingMode::MYSQL_SELF:
     m_radiobutton_server_mysql_selfhosted.set_active();
     break;
 #endif //GLOM_ENABLE_SQLITE
@@ -215,29 +215,29 @@ Document::HostingMode FileChooserDialog_SaveExtras::get_extra_newdb_hosting_mode
 {
 #ifdef GLOM_ENABLE_POSTGRESQL
   if(m_radiobutton_server_postgres_central.get_active())
-    return Document::HOSTING_MODE_POSTGRES_CENTRAL;
+    return Document::HostingMode::POSTGRES_CENTRAL;
   else if(m_radiobutton_server_postgres_selfhosted.get_active())
-    return Document::HOSTING_MODE_POSTGRES_SELF;
+    return Document::HostingMode::POSTGRES_SELF;
 #endif //GLOM_ENABLE_POSTGRESQL
 
 #ifdef GLOM_ENABLE_SQLITE
   if(m_radiobutton_server_sqlite.get_active())
-    return Document::HOSTING_MODE_SQLITE;
+    return Document::HostingMode::SQLITE;
 #endif //GLOM_ENABLE_SQLITE
 
 #ifdef GLOM_ENABLE_MYSQL
   if(m_radiobutton_server_mysql_central.get_active())
-    return Document::HOSTING_MODE_MYSQL_CENTRAL;
+    return Document::HostingMode::MYSQL_CENTRAL;
   else if(m_radiobutton_server_mysql_selfhosted.get_active())
-    return Document::HOSTING_MODE_MYSQL_SELF;
+    return Document::HostingMode::MYSQL_SELF;
 #endif //GLOM_ENABLE_MYSQL
 
   g_assert_not_reached();
 
 #ifdef GLOM_ENABLE_SQLITE
-  return Document::HOSTING_MODE_SQLITE; //Arbitrary
+  return Document::HostingMode::SQLITE; //Arbitrary
 #else
-  return Document::HOSTING_MODE_POSTGRES_SELF; //Arbitrary.
+  return Document::HostingMode::POSTGRES_SELF; //Arbitrary.
 #endif //GLOM_ENABLE_SQLITE
 }
 
